@@ -43,7 +43,7 @@ public:
     Type::Type type() const;
 
     /**
-     * An internal name for the type
+     * An internal unique name for the type
      */
     QString name() const;
 
@@ -52,6 +52,12 @@ public:
      */
     QString displayName() const;
 
+    /**
+     * Construct a TypeInfo from the internal type name.
+     * The internal type name is case insensitive
+     */
+    static TypeInfo fromName(const QString& name);
+
 private:
     class Private;
     Private* d;
